==> apache-VCL-2.4.2.tar.bz2: apache-VCL-2.4.2/web/js/nls/fr_CA/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Create / Update an Image':'Créer / Mettre à jour une image',
'You do not have access to create or update any images.':'Vous ne avez pas accès à créer ou à mettre à jour les images.',
'(New Profile)':'(New Profile)',
'The start day and time must be in the future.':'Le jour et l\'heure de début doivent être à l\'avenir.',
'The end time must be at least 30 minutes in the future.':'L\'heure de fin doit être d\'au moins 30 minutes à l\'avenir.',
'The end time must be after the start time.':'L\'heure de fin doit être postérieure à l\'heure de début.',
'The end time is too close to the start time.':'L\'heure de fin est trop proche de l\'heure de début.',
'Times cannot be suggested for cluster reservations':'Les temps ne peut pas être proposé pour les réservations de munitions',
'Cancel':'Annuler',
'Okay':'Bien',
'Create Reservation':'Créer Réservation',
'Modify Reservation':'Modifier la réservation',
"Create Imaging Reservation":"Créer Imaging Réservation",
"Deploy Server":"Deploy Server",
'Please select a valid environment.':'Se il vous plaît sélectionner un environnement valide.',
'View Available Times':'Voir le temps',
'hour':'heure',
'days':'journées',
'hours':'heures',
"There are multiple versions of this environment available.":"Il existe plusieurs versions de cet environnement disponibles.",
"Please select the version you would like to check out:":"Se il vous plaît sélectionner la version que vous souhaitez consulter:",
'Select Image Revisions':'Sélectionnez Révisions de l\'image',
'Revision':'Révision',
'User':'Utilisateur',
'Created':'Établi',
'Production':'Production',
'Working...':'De travail ...',
'Loading...':'Chargement ...',
"The end time must be later than the start time.":"L'heure de fin doit être postérieure à l'heure de début.",
'The reservation you selected<br>to edit has expired.<br><br>':'La réservation que vous avez sélectionné Comment faire pour modifier a expiré. <br>',
'The reservation you selected<br>to reboot has expired.<br><br>':'La réservation que vous avez sélectionné Comment faire pour redémarrer a expiré. <br>',
'The reservation you selected<br>to reinstall has expired.<br><br>':'La réservation que vous avez sélectionné Comment faire pour réinstaller a expiré. <br>',
'An invalid version was submitted.':'Une version non valide a été soumis.',
'(No description)':'(Pas de description)',
'You do not have access to apply this server profile.':'Vous ne avez pas accès à appliquer ce profil de serveur.',
'Delete':'Effacer',
'Undelete':'Undelete',
'Edit':'Éditer',
'You do not have access to the submitted resource or group':'Vous ne avez pas accès à la ressource ou un groupe soumis',
'Resource In Use':'En cours d\'utilisation des ressources',
'Problem encountered while attempting to delete resource. Please contact a system administrator.':'Problème lors de la tentative de supprimer la ressource. Se il vous plaît contactez l\'administrateur du système.',
'false':'faux',
'true':'vrai',
'Save Changes':'Enregistrer les modifications',
'Access denied to edit this item':'Accès refusé à modifier cet article',
'Invalid network speed specified':'La vitesse du réseau spécifié invalide',
'Max Concurrent Usage must be between 0 and 255':'Max utilisation simultanée doit être comprise entre 0 et 255',
'Invalid value specified for \'Available for checkout\'':'Valeur non valide spécifiée pour \'Disponible pour la caisse \'',
'Invalid value specified for \'Check for logged in user\'':'Valeur non valide spécifiée pour \'Vérifier connecté \' utilisateur',
'Invalid value specified for \'Users have administrative access\'':'Valeur non valide spécifiée pour \'utilisateurs ne ont accès administratif \'',
'Invalid value specified for \'Set computer hostname\'':'Définir le nom d\'hôte de l\'ordinateur',
'Invalid value specified for \'Use sysprep\'':'Valeur non valide spécifiée pour \'utilisation sysprep \'',
'Invalid Connect Methods specified':'Méthodes Connect invalides indiquées',
'Add Subimage':'Ajouter sous-image',
'(None)':'(Aucun)',
'Remove Selected Subimage(s)':'Supprimer sous-image sélectionnée (s)',
'Add Method':'Ajouter Méthode',
'There must be at least one item in Current Methods':'Il doit y avoir au moins un article dans les méthodes actuelles',
'Remove Selected Methods':'Retirer Méthodes sélectionnés',
'You cannot delete the production revision.':'Vous ne pouvez pas supprimer la révision de production.',
'Create Image':'Créer une image',
'You must be the owner of the image to update it.':'Vous devez être le propriétaire de l\'image à mettre à jour.',
"Remove":"Supprimer",
'The selected Block Request no longer exists.':'Le Bloc demande sélectionnée ne existe plus.',
'These times overlap with an existing time slot':'Ces temps se chevauchent avec un intervalle de temps existant',
'The date must be today or later':'La date doit être aujourd\'hui ou plus tard',
'The date and times overlap with an existing time slot':'La date et les heures se chevauchent avec un intervalle de temps existant',
'Please fix invalid values before submitting.':'Se il vous plaît fixer des valeurs invalides avant de soumettre.',
'Please fill in First Date of Usage':'Se il vous plaît remplir First Date d`utilisation',
'Please fill in Last Date of Usage':'Se il vous plaît remplir Date de dernière utilisation',
'The First Date of Usage must be today or later':'La première date de Usage doit être aujourd\'hui ou plus tard',
'The Last Date of Usage must be the same or later than the First Date of Usage':'La dernière date de Usage doit être le même ou plus tard que la première date d`utilisation',
'The Last Date of Usage must be today or later':'La dernière date de Usage doit être aujourd\'hui ou plus tard',
'Sunday':'Dimanche',
'Monday':'Lundi',
'Tuesday':'Mardi',
'Wednesday':'Mercredi',
'Thursday':'Jeudi',
'Friday':'Vendredi',
'Saturday':'Samedi',
'At least one day must be checked when using \'Repeating Weekly\'':'Au moins un jour doit être vérifié lors de l\'utilisation \'Répétition hebdomadaire \'',
'At least one start/end combination must be entered when using \'Repeating Weekly\'':'Au moins une combinaison de début / fin doit être saisi lors de l\'utilisation \'Répétition hebdomadaire \'',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.':'Lors de la présentation "(groupe ne figure pas)" comme le groupe d\'utilisateurs, l\'information doit être incluse dans les commentaires au sujet de ce groupe doit être créé.',
'Name:':'Nom:',
'Owner:':'Propriétaire:',
'specified in comments':'spécifiée dans les commentaires',
'Weekly':'Hebdomadaire',
'First Date:':'First Date:',
'Last Date:':'Dernière Date:',
'Repeating on these days:':'Répétition sur ces jours:',
'During these times:':'Pendant ces périodes:',
'At least one start/end combination must be entered when using \'Repeating Monthly\'':'Au moins une combinaison de début / fin doit être saisi lors de l\'utilisation \'Répétition mensuel \'',
'Monthly':'Mensuel',
'Repeat on:':'Répéter l\'opération sur:',
"of each month":"de chaque mois",
'At least one date/start/end combination must be entered when using \'List of Dates/Times\'':'Au moins une date / START / combinaison de fin doit être saisi lors de l\'utilisation \'Liste des dates / heures \'',
'List of Dates/Times':'Liste des dates / heures',
'User Submitted Comments:':'Soumis utilisateur Commentaires:',
'Skip':'Sauter',
'Use':'Utilisation',
'Total online:':'Total en ligne:'
}

==> apache-VCL-2.5.1.tar.bz2: apache-VCL-2.5.1/web/js/nls/fr_CA/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Create / Update an Image':'Créer / Mettre à jour une image',
'You do not have access to create or update any images.':'Vous ne avez pas accès à créer ou à mettre à jour les images.',
'(New Profile)':'',
'The start day and time must be in the future.':'Le jour et l\'heure de début doivent être à l\'avenir.',
'The end time must be at least 30 minutes in the future.':'L\'heure de fin doit être d\'au moins 30 minutes à l\'avenir.',
'The end time must be after the start time.':'L\'heure de fin doit être postérieure à l\'heure de début.',
'The end time is too close to the start time.':'L\'heure de fin est trop proche de l\'heure de début.',
'The submitted start time is in the past.':'L\'heure de début saisie est passée',
'Times cannot be suggested for cluster reservations':'Les temps ne peut pas être proposé pour les réservations de munitions',
'Cancel':'Annuler',
'Okay':'Bien',
'Create Reservation':'Créer Réservation',
'Modify Reservation':'Modifier la réservation',
'Create Imaging Reservation':"Créer Imaging Réservation",
'Deploy Server":"Deploy Server',
'Please select a valid environment.':'Se il vous plaît sélectionner un environnement valide.',
'View Available Times':'Voir le temps',
'hour':'heure',
'weeks':'',
'days':'journées',
'hours':'heures',
'There are multiple versions of this environment available.':"Il existe plusieurs versions de cet environnement disponibles.",
'Please select the version you would like to check out:':"Se il vous plaît sélectionner la version que vous souhaitez consulter:",
'Select Image Revisions':'Sélectionnez Révisions de l\'image',
'Revision':'Révision',
'User':'Utilisateur',
'Created':'Établi',
'Production':'Production',
'Working...':'De travail ...',
'Loading...':'Chargement ...',
'The end time must be later than the start time.':"L'heure de fin doit être postérieure à l'heure de début.",
'The reservation you selected<br>to edit has expired.<br><br>':'La réservation que vous avez sélectionné Comment faire pour modifier a expiré. <br>',
'The reservation you selected<br>to reboot has expired.<br><br>':'La réservation que vous avez sélectionné Comment faire pour redémarrer a expiré. <br>',
'The reservation you selected<br>to reinstall has expired.<br><br>':'La réservation que vous avez sélectionné Comment faire pour réinstaller a expiré. <br>',
'An invalid version was submitted.':'Une version non valide a été soumis.',
'(No description)':'(Pas de description)',
'You do not have access to apply this server profile.':'Vous ne avez pas accès à appliquer ce profil de serveur.',
'Delete':'Effacer',
'Undelete':'Undelete',
'Edit':'Éditer',
'You do not have access to the submitted resource or group':'Vous ne avez pas accès à la ressource ou un groupe soumis',
'Resource In Use':'En cours d\'utilisation des ressources',
'Problem encountered while attempting to delete resource. Please contact a system administrator.':'Problème lors de la tentative de supprimer la ressource. Se il vous plaît contactez l\'administrateur du système.',
'Unmatched or empty brackets ( [ and ] ) in subject':'',
'Unmatched or empty brackets ( [ and ] ) in message':'',
'Unmatched or empty brackets ( [ and ] ) in short message':'',
'false':'faux',
'true':'vrai',
'Save Changes':'Enregistrer les modifications',
'Access denied to edit this item':'Accès refusé à modifier cet article',
'Invalid network speed specified':'La vitesse du réseau spécifié invalide',
'Max Concurrent Usage must be between 0 and 255':'Max utilisation simultanée doit être comprise entre 0 et 255',
'Invalid value specified for \'Available for checkout\'':'Valeur non valide spécifiée pour \'Disponible pour la caisse \'',
'Invalid value specified for \'Check for logged in user\'':'Valeur non valide spécifiée pour \'Vérifier connecté \' utilisateur',
'Invalid value specified for \'Users have administrative access\'':'Valeur non valide spécifiée pour \'utilisateurs ne ont accès administratif \'',
'Invalid value specified for \'Set computer hostname\'':'Définir le nom d\'hôte de l\'ordinateur',
'Invalid value specified for \'Use sysprep\'':'Valeur non valide spécifiée pour \'utilisation sysprep \'',
'Invalid Connect Methods specified':'Méthodes Connect invalides indiquées',
'Add Subimage':'Ajouter sous-image',
'(None)':'(Aucun)',
'Remove Selected Subimage(s)':'Supprimer sous-image sélectionnée (s)',
'Add Method':'Ajouter Méthode',
'There must be at least one item in Current Methods':'Il doit y avoir au moins un article dans les méthodes actuelles',
'Remove Selected Methods':'Retirer Méthodes sélectionnés',
'You cannot delete the production revision.':'Vous ne pouvez pas supprimer la révision de production.',
'Create Image':'Créer une image',
'You must be the owner of the image to update it.':'Vous devez être le propriétaire de l\'image à mettre à jour.',
'Remove':"Supprimer",
'The selected Block Request no longer exists.':'Le Bloc demande sélectionnée ne existe plus.',
'These times overlap with an existing time slot':'Ces temps se chevauchent avec un intervalle de temps existant',
'The date must be today or later':'La date doit être aujourd\'hui ou plus tard',
'The date and times overlap with an existing time slot':'La date et les heures se chevauchent avec un intervalle de temps existant',
'Please fix invalid values before submitting.':'Se il vous plaît fixer des valeurs invalides avant de soumettre.',
'Please fill in First Date of Usage':'Se il vous plaît remplir First Date d`utilisation',
'Please fill in Last Date of Usage':'Se il vous plaît remplir Date de dernière utilisation',
'The First Date of Usage must be today or later':'La première date de Usage doit être aujourd\'hui ou plus tard',
'The Last Date of Usage must be the same or later than the First Date of Usage':'La dernière date de Usage doit être le même ou plus tard que la première date d`utilisation',
'The Last Date of Usage must be today or later':'La dernière date de Usage doit être aujourd\'hui ou plus tard',
'Sunday':'Dimanche',
'Monday':'Lundi',
'Tuesday':'Mardi',
'Wednesday':'Mercredi',
'Thursday':'Jeudi',
'Friday':'Vendredi',
'Saturday':'Samedi',
'At least one day must be checked when using "Repeating Weekly"':'Au moins un jour doit être vérifié lors de l\'utilisation "Répétition hebdomadaire"',
'At least one start/end combination must be entered when using "Repeating Weekly"':'Au moins une combinaison de début / fin doit être saisi lors de l\'utilisation "Répétition hebdomadaire"',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.':'Lors de la présentation "(groupe ne figure pas)" comme le groupe d\'utilisateurs, l\'information doit être incluse dans les commentaires au sujet de ce groupe doit être créé.',
'Name:':'Nom:',
'Owner:':'Propriétaire:',
'specified in comments':'spécifiée dans les commentaires',
'Weekly':'Hebdomadaire',
'First Date:':'Premi&egrave;re Date:',
'Last Date:':'Dernière Date:',
'Repeating on these days:':'Répétition sur ces jours:',
'During these times:':'Pendant ces périodes:',
'At least one start/end combination must be entered when using \'Repeating Monthly\'':'Au moins une combinaison de début / fin doit être saisi lors de l\'utilisation \'Répétition mensuel \'',
'Monthly':'Mensuel',
'Repeat on:':'Répéter l\'opération sur:',
'of each month':"de chaque mois",
'At least one date/start/end combination must be entered when using \'List of Dates/Times\'':'Au moins une date / START / combinaison de fin doit être saisi lors de l\'utilisation \'Liste des dates / heures \'',
'List of Dates/Times':'Liste des dates / heures',
'User Submitted Comments:':'Soumis utilisateur Commentaires:',
'Skip':'Sauter',
'Use':'Utilisation',
'Total online:':'Total en ligne:',
'match':'',
'no match':'',
'Error encountered:':'',
'Please try again later':'',
'Values updated':'',
'Submit Changes':'',
'Add':'',
'Invalid item selected for new value':'',
'Invalid value submitted':'',
'Invalid item submitted for deletion':'',
'You do not have access to modify the submitted settings.':'',
'Invalid value submitted for ':'',
'NFS Mounts':'',
'NFS Mounts are NFS exports that are to be mounted within each reservation deployed by a given management node.<br>Values must be like':'',
'Invalid value - must be in the form':'',
'Messages':'',
'This section allows for configuration of messages that are sent to users and administrators about things such as reservations and image management. Every message has a default. Additionally, separate messages can be configured for each affiliation. Most of the messages will have parts that are in square brackets. These parts will have data substituted for them before the message is sent. A list of what can be used in squeare brackets can be found at the <a href=\"%s\">Apache VCL web site</a>. Some messages also have a short form that may be sent such as in the form of a popup within a reservation when the reservation is about to end.':'',
'Save Message':'',
'Delete Message and Use Default':'',
'The following messages have invalid items included for substitution. Please correct the message contents and save them again for the backend to validate.':'',
'Message type %s for affiliation %s successfully deleted':'',
'Invalid item submitted to save':'',
'Message successfully saved':'',
'No changes to submitted message. Nothing saved.':'',
'unset':'',
'1 hour':'',
'Default for User':'',
'Invalid Max Reservation Duration selected':'',
'minutes':'',
'Passwords do not match':''
}
